==> zio-aws-sagemaker_3-5.17.146.1-sources.jar: zio/aws/sagemaker/model/BatchDescribeModelPackageSummary.scala <==
package zio.aws.sagemaker.model
import zio.aws.sagemaker.model.primitives.{
  CreationTime,
  ModelPackageVersion,
  ModelPackageArn,
  EntityDescription,
  EntityName
}
import java.time.Instant
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class BatchDescribeModelPackageSummary(
    modelPackageGroupName: EntityName,
    modelPackageVersion: Option[ModelPackageVersion] = None,
    modelPackageArn: ModelPackageArn,
    modelPackageDescription: Option[EntityDescription] = None,
    creationTime: CreationTime,
    inferenceSpecification: zio.aws.sagemaker.model.InferenceSpecification,
    modelPackageStatus: zio.aws.sagemaker.model.ModelPackageStatus,
    modelApprovalStatus: Option[zio.aws.sagemaker.model.ModelApprovalStatus] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.BatchDescribeModelPackageSummary = {
    import BatchDescribeModelPackageSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.BatchDescribeModelPackageSummary
      .builder()
      .modelPackageGroupName(
        EntityName.unwrap(modelPackageGroupName): java.lang.String
      )
      .optionallyWith(
        modelPackageVersion.map(value =>
          ModelPackageVersion.unwrap(value): Integer
        )
      )(_.modelPackageVersion)
      .modelPackageArn(
        ModelPackageArn.unwrap(modelPackageArn): java.lang.String
      )
      .optionallyWith(
        modelPackageDescription.map(value =>
          EntityDescription.unwrap(value): java.lang.String
        )
      )(_.modelPackageDescription)
      .creationTime(CreationTime.unwrap(creationTime): Instant)
      .inferenceSpecification(inferenceSpecification.buildAwsValue())
      .modelPackageStatus(modelPackageStatus.unwrap)
      .optionallyWith(modelApprovalStatus.map(value => value.unwrap))(
        _.modelApprovalStatus
      )
      .build()
  }
  def asReadOnly
      : zio.aws.sagemaker.model.BatchDescribeModelPackageSummary.ReadOnly =
    zio.aws.sagemaker.model.BatchDescribeModelPackageSummary
      .wrap(buildAwsValue())
}
object BatchDescribeModelPackageSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.BatchDescribeModelPackageSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.BatchDescribeModelPackageSummary =
      zio.aws.sagemaker.model.BatchDescribeModelPackageSummary(
        modelPackageGroupName,
        modelPackageVersion.map(value => value),
        modelPackageArn,
        modelPackageDescription.map(value => value),
        creationTime,
        inferenceSpecification.asEditable,
        modelPackageStatus,
        modelApprovalStatus.map(value => value)
      )
    def modelPackageGroupName: EntityName
    def modelPackageVersion: Option[ModelPackageVersion]
    def modelPackageArn: ModelPackageArn
    def modelPackageDescription: Option[EntityDescription]
    def creationTime: CreationTime
    def inferenceSpecification
        : zio.aws.sagemaker.model.InferenceSpecification.ReadOnly
    def modelPackageStatus: zio.aws.sagemaker.model.ModelPackageStatus
    def modelApprovalStatus: Option[zio.aws.sagemaker.model.ModelApprovalStatus]
    def getModelPackageGroupName: ZIO[Any, Nothing, EntityName] =
      ZIO.succeed(modelPackageGroupName)
    def getModelPackageVersion: ZIO[Any, AwsError, ModelPackageVersion] =
      AwsError.unwrapOptionField("modelPackageVersion", modelPackageVersion)
    def getModelPackageArn: ZIO[Any, Nothing, ModelPackageArn] =
      ZIO.succeed(modelPackageArn)
    def getModelPackageDescription: ZIO[Any, AwsError, EntityDescription] =
      AwsError.unwrapOptionField(
        "modelPackageDescription",
        modelPackageDescription
      )
    def getCreationTime: ZIO[Any, Nothing, CreationTime] =
      ZIO.succeed(creationTime)
    def getInferenceSpecification: ZIO[
      Any,
      Nothing,
      zio.aws.sagemaker.model.InferenceSpecification.ReadOnly
    ] = ZIO.succeed(inferenceSpecification)
    def getModelPackageStatus
        : ZIO[Any, Nothing, zio.aws.sagemaker.model.ModelPackageStatus] =
      ZIO.succeed(modelPackageStatus)
    def getModelApprovalStatus
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.ModelApprovalStatus] =
      AwsError.unwrapOptionField("modelApprovalStatus", modelApprovalStatus)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.BatchDescribeModelPackageSummary
  ) extends zio.aws.sagemaker.model.BatchDescribeModelPackageSummary.ReadOnly {
    override val modelPackageGroupName: EntityName =
      zio.aws.sagemaker.model.primitives
        .EntityName(impl.modelPackageGroupName())
    override val modelPackageVersion: Option[ModelPackageVersion] = scala
      .Option(impl.modelPackageVersion())
      .map(value =>
        zio.aws.sagemaker.model.primitives.ModelPackageVersion(value)
      )
    override val modelPackageArn: ModelPackageArn =
      zio.aws.sagemaker.model.primitives.ModelPackageArn(impl.modelPackageArn())
    override val modelPackageDescription: Option[EntityDescription] = scala
      .Option(impl.modelPackageDescription())
      .map(value => zio.aws.sagemaker.model.primitives.EntityDescription(value))
    override val creationTime: CreationTime =
      zio.aws.sagemaker.model.primitives.CreationTime(impl.creationTime())
    override val inferenceSpecification
        : zio.aws.sagemaker.model.InferenceSpecification.ReadOnly =
      zio.aws.sagemaker.model.InferenceSpecification
        .wrap(impl.inferenceSpecification())
    override val modelPackageStatus
        : zio.aws.sagemaker.model.ModelPackageStatus =
      zio.aws.sagemaker.model.ModelPackageStatus.wrap(impl.modelPackageStatus())
    override val modelApprovalStatus
        : Option[zio.aws.sagemaker.model.ModelApprovalStatus] = scala
      .Option(impl.modelApprovalStatus())
      .map(value => zio.aws.sagemaker.model.ModelApprovalStatus.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.BatchDescribeModelPackageSummary
  ): zio.aws.sagemaker.model.BatchDescribeModelPackageSummary.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-sagemaker_3-5.17.295.5-sources.jar: zio/aws/sagemaker/model/BatchDescribeModelPackageSummary.scala <==
package zio.aws.sagemaker.model
import zio.aws.sagemaker.model.primitives.{
  CreationTime,
  ModelPackageVersion,
  ModelPackageArn,
  EntityDescription,
  EntityName
}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class BatchDescribeModelPackageSummary(
    modelPackageGroupName: EntityName,
    modelPackageVersion: Optional[ModelPackageVersion] = Optional.Absent,
    modelPackageArn: ModelPackageArn,
    modelPackageDescription: Optional[EntityDescription] = Optional.Absent,
    creationTime: CreationTime,
    inferenceSpecification: zio.aws.sagemaker.model.InferenceSpecification,
    modelPackageStatus: zio.aws.sagemaker.model.ModelPackageStatus,
    modelApprovalStatus: Optional[zio.aws.sagemaker.model.ModelApprovalStatus] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.BatchDescribeModelPackageSummary = {
    import BatchDescribeModelPackageSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.BatchDescribeModelPackageSummary
      .builder()
      .modelPackageGroupName(
        EntityName.unwrap(modelPackageGroupName): java.lang.String
      )
      .optionallyWith(
        modelPackageVersion.map(value =>
          ModelPackageVersion.unwrap(value): Integer
        )
      )(_.modelPackageVersion)
      .modelPackageArn(
        ModelPackageArn.unwrap(modelPackageArn): java.lang.String
      )
      .optionallyWith(
        modelPackageDescription.map(value =>
          EntityDescription.unwrap(value): java.lang.String
        )
      )(_.modelPackageDescription)
      .creationTime(CreationTime.unwrap(creationTime): Instant)
      .inferenceSpecification(inferenceSpecification.buildAwsValue())
      .modelPackageStatus(modelPackageStatus.unwrap)
      .optionallyWith(modelApprovalStatus.map(value => value.unwrap))(
        _.modelApprovalStatus
      )
      .build()
  }
  def asReadOnly
      : zio.aws.sagemaker.model.BatchDescribeModelPackageSummary.ReadOnly =
    zio.aws.sagemaker.model.BatchDescribeModelPackageSummary
      .wrap(buildAwsValue())
}
object BatchDescribeModelPackageSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.BatchDescribeModelPackageSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.BatchDescribeModelPackageSummary =
      zio.aws.sagemaker.model.BatchDescribeModelPackageSummary(
        modelPackageGroupName,
        modelPackageVersion.map(value => value),
        modelPackageArn,
        modelPackageDescription.map(value => value),
        creationTime,
        inferenceSpecification.asEditable,
        modelPackageStatus,
        modelApprovalStatus.map(value => value)
      )
    def modelPackageGroupName: EntityName
    def modelPackageVersion: Optional[ModelPackageVersion]
    def modelPackageArn: ModelPackageArn
    def modelPackageDescription: Optional[EntityDescription]
    def creationTime: CreationTime
    def inferenceSpecification
        : zio.aws.sagemaker.model.InferenceSpecification.ReadOnly
    def modelPackageStatus: zio.aws.sagemaker.model.ModelPackageStatus
    def modelApprovalStatus
        : Optional[zio.aws.sagemaker.model.ModelApprovalStatus]
    def getModelPackageGroupName: ZIO[Any, Nothing, EntityName] =
      ZIO.succeed(modelPackageGroupName)
    def getModelPackageVersion: ZIO[Any, AwsError, ModelPackageVersion] =
      AwsError.unwrapOptionField("modelPackageVersion", modelPackageVersion)
    def getModelPackageArn: ZIO[Any, Nothing, ModelPackageArn] =
      ZIO.succeed(modelPackageArn)
    def getModelPackageDescription: ZIO[Any, AwsError, EntityDescription] =
      AwsError.unwrapOptionField(
        "modelPackageDescription",
        modelPackageDescription
      )
    def getCreationTime: ZIO[Any, Nothing, CreationTime] =
      ZIO.succeed(creationTime)
    def getInferenceSpecification: ZIO[
      Any,
      Nothing,
      zio.aws.sagemaker.model.InferenceSpecification.ReadOnly
    ] = ZIO.succeed(inferenceSpecification)
    def getModelPackageStatus
        : ZIO[Any, Nothing, zio.aws.sagemaker.model.ModelPackageStatus] =
      ZIO.succeed(modelPackageStatus)
    def getModelApprovalStatus
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.ModelApprovalStatus] =
      AwsError.unwrapOptionField("modelApprovalStatus", modelApprovalStatus)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.BatchDescribeModelPackageSummary
  ) extends zio.aws.sagemaker.model.BatchDescribeModelPackageSummary.ReadOnly {
    override val modelPackageGroupName: EntityName =
      zio.aws.sagemaker.model.primitives
        .EntityName(impl.modelPackageGroupName())
    override val modelPackageVersion: Optional[ModelPackageVersion] =
      zio.aws.core.internal
        .optionalFromNullable(impl.modelPackageVersion())
        .map(value =>
          zio.aws.sagemaker.model.primitives.ModelPackageVersion(value)
        )
    override val modelPackageArn: ModelPackageArn =
      zio.aws.sagemaker.model.primitives.ModelPackageArn(impl.modelPackageArn())
    override val modelPackageDescription: Optional[EntityDescription] =
      zio.aws.core.internal
        .optionalFromNullable(impl.modelPackageDescription())
        .map(value =>
          zio.aws.sagemaker.model.primitives.EntityDescription(value)
        )
    override val creationTime: CreationTime =
      zio.aws.sagemaker.model.primitives.CreationTime(impl.creationTime())
    override val inferenceSpecification
        : zio.aws.sagemaker.model.InferenceSpecification.ReadOnly =
      zio.aws.sagemaker.model.InferenceSpecification
        .wrap(impl.inferenceSpecification())
    override val modelPackageStatus
        : zio.aws.sagemaker.model.ModelPackageStatus =
      zio.aws.sagemaker.model.ModelPackageStatus.wrap(impl.modelPackageStatus())
    override val modelApprovalStatus
        : Optional[zio.aws.sagemaker.model.ModelApprovalStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.modelApprovalStatus())
        .map(value => zio.aws.sagemaker.model.ModelApprovalStatus.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.BatchDescribeModelPackageSummary
  ): zio.aws.sagemaker.model.BatchDescribeModelPackageSummary.ReadOnly =
    new Wrapper(impl)
}
